Introduction — PyOEIS 1.0 documentation

# Introduction

The Online Encyclopedia of Integer Sequences (OEIS) is a database of integer sequences. It contains many well-known sequences, such as the primes and Fibonacci numbers as well as many more obscure sequences.

PyOEIS allows for the searching of the OEIS from within Python, as well as allowing you to access sequence information through `Sequence` objects.

## OEIS Search Syntax and Other Useful Links

While PyOEIS provides many porcelain methods which allow you to search by sequence ID, author etc., it is also possible to query the OEIS using its usual search syntax (as you would on the website). It may also be useful to understand how the OEIS operates for debugging purposes. The following links may therefore be of use:

- Hints and search syntax
- Explanation of the OEIS internal format (which PyOEIS is built upon)
- Explanation of the fields in each sequence entry